﻿using System;
using System.Windows.Forms;
using PerpetuumSoft.Reporting.Components;
using PerpetuumSoft.Reporting.View;

namespace FertilityRateAndLifeExpectancy
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            LoadData();
            reportSlot.RenderCompleted += PreviewReport;
        }

        /// <summary>
        /// Generates some data for our report.
        /// </summary>
        private void LoadData()
        {
            var rows = fertilityInfoTable.Rows;

            //      fertility, life expectancy, population, country (same order as in the designer)
            rows.Add(6.6,      43.95,           29021099,  "Afganistan");
            rows.Add(2.54,     51.48,           48687000,  "South Africa");
            rows.Add(1.42,     70.63,           9680850,   "Belarus");
            rows.Add(1.34,     82.59,           127704000, "Japan");
        }

        /// <summary>
        /// Displays the prepared report. 
        /// 
        /// Due to asyncronous nature of Sharp-Shooter, 
        /// a report gets generated on a separate thread
        /// and this handler gets called when the generation
        /// is done. Here we don't always need to show a dialog: 
        /// we could have saved the report, export it, etc.
        /// </summary>
        /// <param name="sender">Report slot that has been just rendered.</param>
        /// <param name="e">Not used, is here because of C# coding convention.</param>
        private void PreviewReport(object sender, EventArgs e)
        {
            using (var form = new PreviewForm((IReportSource)sender)) {
                form.WindowState = FormWindowState.Maximized;
                form.ShowDialog(this);
            }
        }

        /// <summary>
        /// Generates the report. 
        /// 
        /// Because of asynchronous nature of Sharp-Shooter, 
        /// technically it's not correct to say that the report 
        /// is being DISPLAYED in this method. Here we only 
        /// start the process of "preparing" the report, and 
        /// once that is done then our PreviewReport handler gets called.
        /// </summary>
        /// <param name="sender">Button that was clicked.</param>
        /// <param name="e">Info about mouse click, in our case not needed.</param>
        private void btnPreview_Click(object sender, EventArgs e)
        {
            reportSlot.Prepare();
        }
    }
}
